Lucas Chen has uploaded this change for review.

View Change

mb/google/kukui: add support different ram table for Willow

Add support different ram id table base on board_id.

BUG=b:160288021
BRANCH=kukui
TEST=emerge-jacuzzi coreboot

Signed-off-by: Lucas Chen <lucas.chen@quanta.corp-partner.google.com>
Change-Id: Icee922c647774f755d41bc3c37f6a0d5ffc35df1
---
M src/mainboard/google/kukui/boardid.c
1 file changed, 11 insertions(+), 2 deletions(-)

git pull ssh://review.coreboot.org:29418/coreboot refs/changes/89/45289/1
diff --git a/src/mainboard/google/kukui/boardid.c b/src/mainboard/google/kukui/boardid.c
old mode 100644
new mode 100755
index 548f36b..546247e
--- a/src/mainboard/google/kukui/boardid.c
+++ b/src/mainboard/google/kukui/boardid.c
@@ -112,8 +112,17 @@

if (cached_ram_code == BOARD_ID_INIT) {
cached_ram_code = get_adc_index(RAM_ID_CHANNEL);
- /* Model-specific offset - see sdram_configs.c for details. */
- cached_ram_code += CONFIG_BOARD_SDRAM_TABLE_OFFSET;
+ /* Quirk for Willow: All Rev greater then 5 set SDRAM TABLE OFFSET=0x10. */
+ if (CONFIG(BOARD_GOOGLE_WILLOW)) {
+ if (board_id() >= 6) {
+ cached_ram_code += 0x10;
+ }
+ else
+ cached_ram_code += CONFIG_BOARD_SDRAM_TABLE_OFFSET;
+ }
+ else
+ /* Model-specific offset - see sdram_configs.c for details. */
+ cached_ram_code += CONFIG_BOARD_SDRAM_TABLE_OFFSET;
}
return cached_ram_code;
}

To view, visit change 45289. To unsubscribe, or for help writing mail filters, visit settings.

Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: Icee922c647774f755d41bc3c37f6a0d5ffc35df1
Gerrit-Change-Number: 45289
Gerrit-PatchSet: 1
Gerrit-Owner: Lucas Chen <lucas.chen@quanta.corp-partner.google.com>
Gerrit-MessageType: newchange